@@ -1,3 +1,6 @@
+"""
+Minimal Domoticz types for static typing and mocking in tests.
+"""
 from typing import Dict, Optional
 
 
@@ -21,6 +24,9 @@ class DomoticzUnit:
     def Update(self, Log: bool) -> None:
         ...
 
+    def Delete(self) -> None:
+        ...
+
 
 class DomoticzEx:
     @classmethod
